
.. _core-developers-team:

Core Developers
---------------

NetworkX development is guided by the following core team:



.. raw:: html

   <div class="team-member">
     <a href="https://github.com/boothby" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/569654?u=c29b79275293c22fa3c56a06ed04e004465ef331&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @boothby"
           />
        </div>
        Kelly Boothby
     </a>
     <div class="team-member-handle">@boothby</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/dschult" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/915037?u=6a27f396c666c5c2172a1cfc7b0d4bbcd0069eed&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @dschult"
           />
        </div>
        Dan Schult
     </a>
     <div class="team-member-handle">@dschult</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/hagberg" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/187875?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @hagberg"
           />
        </div>
        Aric Hagberg
     </a>
     <div class="team-member-handle">@hagberg</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/jarrodmillman" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/123428?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @jarrodmillman"
           />
        </div>
        Jarrod Millman
     </a>
     <div class="team-member-handle">@jarrodmillman</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/mjschwenne" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/19698215?u=96f60d2e90261aa7487fffcc2ebad1158028ecd5&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @mjschwenne"
           />
        </div>
        Matt Schwennesen
     </a>
     <div class="team-member-handle">@mjschwenne</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/MridulS" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/5363860?u=ce5c6e9388d2fd153ebf8b0bb521c928b0813608&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @MridulS"
           />
        </div>
        Mridul Seth
     </a>
     <div class="team-member-handle">@MridulS</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/paulitapb" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/44149844?u=9bba3eec362015b3e8ce08a18a58bce4a33361da&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @paulitapb"
           />
        </div>
        Paula Pérez Bianchi
     </a>
     <div class="team-member-handle">@paulitapb</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/rossbar" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/1268991?u=974707b96081a9705f3a239c0773320f353ee02f&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @rossbar"
           />
        </div>
        Ross Barnowski
     </a>
     <div class="team-member-handle">@rossbar</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/stefanv" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/45071?u=c779b5e06448fbc638bc987cdfe305c7f9a7175e&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @stefanv"
           />
        </div>
        Stefan van der Walt
     </a>
     <div class="team-member-handle">@stefanv</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/z3y50n" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/33282622?u=66483bb152faad7fcdb80cb9d1f8b6d391e448bc&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @z3y50n"
           />
        </div>
        Dimitrios Papageorgiou
     </a>
     <div class="team-member-handle">@z3y50n</div>
   </div>



Emeritus Developers
-------------------

We thank these previously-active core developers for their contributions to NetworkX.



.. raw:: html

   <div class="team-member">
     <a href="https://github.com/bjedwards" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/726274?u=a74ad0658212200d837ffb1ce549b32f0e99f3c6&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @bjedwards"
           />
        </div>
        Benjamin Edwards
     </a>
     <div class="team-member-handle">@bjedwards</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/camillescott" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/2896301?u=bd57c546510c131f4f7f41e3999fb8e6e33a2298&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @camillescott"
           />
        </div>
        Camille Scott
     </a>
     <div class="team-member-handle">@camillescott</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/chebee7i" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/326005?u=a5a33cadf55b2fbdd8b033517f97f763563aa72a&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @chebee7i"
           />
        </div>
        @chebee7i
     </a>
     <div class="team-member-handle">@chebee7i</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/ericmjl" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/2631566?u=c5d73d769c251a862d7d4bbf1119297d8085c34c&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @ericmjl"
           />
        </div>
        Eric Ma
     </a>
     <div class="team-member-handle">@ericmjl</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/harshal-dupare" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/52428908?u=4538fa6338afe2b9460f2f5a4238cadb38f8ef2e&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @harshal-dupare"
           />
        </div>
        Harshal Dupare
     </a>
     <div class="team-member-handle">@harshal-dupare</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/jfinkels" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/121755?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @jfinkels"
           />
        </div>
        @jfinkels
     </a>
     <div class="team-member-handle">@jfinkels</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/jtorrents" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/1184374?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @jtorrents"
           />
        </div>
        Jordi Torrents
     </a>
     <div class="team-member-handle">@jtorrents</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/loicseguin" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/812562?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @loicseguin"
           />
        </div>
        Loïc Séguin-Charbonneau
     </a>
     <div class="team-member-handle">@loicseguin</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/vadyushkins" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/43042296?u=01411ddb7d394274117007e8d29019e091a8e00a&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @vadyushkins"
           />
        </div>
        Vadim Abzalov
     </a>
     <div class="team-member-handle">@vadyushkins</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/ysitu" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/7018196?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @ysitu"
           />
        </div>
        @ysitu
     </a>
     <div class="team-member-handle">@ysitu</div>
   </div>


.. _steering-council-team:

Steering Council
----------------




.. raw:: html

   <div class="team-member">
     <a href="https://github.com/dschult" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/915037?u=6a27f396c666c5c2172a1cfc7b0d4bbcd0069eed&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @dschult"
           />
        </div>
        Dan Schult
     </a>
     <div class="team-member-handle">@dschult</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/hagberg" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/187875?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @hagberg"
           />
        </div>
        Aric Hagberg
     </a>
     <div class="team-member-handle">@hagberg</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/jarrodmillman" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/123428?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @jarrodmillman"
           />
        </div>
        Jarrod Millman
     </a>
     <div class="team-member-handle">@jarrodmillman</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/MridulS" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/5363860?u=ce5c6e9388d2fd153ebf8b0bb521c928b0813608&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @MridulS"
           />
        </div>
        Mridul Seth
     </a>
     <div class="team-member-handle">@MridulS</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/rossbar" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/1268991?u=974707b96081a9705f3a239c0773320f353ee02f&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @rossbar"
           />
        </div>
        Ross Barnowski
     </a>
     <div class="team-member-handle">@rossbar</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/stefanv" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars.githubusercontent.com/u/45071?u=c779b5e06448fbc638bc987cdfe305c7f9a7175e&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @stefanv"
           />
        </div>
        Stefan van der Walt
     </a>
     <div class="team-member-handle">@stefanv</div>
   </div>

